from enum import Enum
from typing import List, Optional, Tuple, TypedDict

from encord_active_components.renderer import Components, render


class ProjectStats(TypedDict):
    dataUnits: int
    labels: int
    classes: int


class Project(TypedDict):
    name: str
    hash: str
    imageUrl: str
    sandbox: bool
    path: Optional[str]
    stats: Optional[ProjectStats]


class OutputAction(str, Enum):
    SELECT_SANDBOX_PROJECT = "SELECT_SANDBOX_PROJECT"
    SELECT_USER_PROJECT = "SELECT_USER_PROJECT"
    IMPORT_ENCORD = "IMPORT_ENCORD"
    IMPORT_COCO = "IMPORT_COCO"
    INIT = "INIT"


def projects_page(projects: List[Project] = []) -> Optional[Tuple[OutputAction, str]]:
    return render(component=Components.PROJECT_SELECTION, props={"projects": projects})


if __name__ == "__main__":
    pass
    # key = pages_menu(ITEMS)



from enum import Enum
from os import environ
from pathlib import Path

from streamlit.components.v1.components import declare_component

_RELEASE = environ.get("RELEASE", "TRUE")

if _RELEASE == "TRUE":
    build_dir = (Path(__file__).parent / "frontend/dist").expanduser().resolve()
    render = declare_component("frontend_components", path=build_dir.as_posix())
else:
    render = declare_component("frontend_components", url="http://localhost:5173")


class Components(str, Enum):
    PAGES_MENU = "PagesMenu"
    PROJECT_SELECTION = "ProjectsPage"
